@@ -4,7 +4,7 @@ use warnings;
 use 5.006;
 
 package HTTP::BrowserDetect;
-$HTTP::BrowserDetect::VERSION = '2.07';
+$HTTP::BrowserDetect::VERSION = '2.08';
 use vars qw(@ALL_TESTS);
 
 # Operating Systems
@@ -76,7 +76,7 @@ our @BROWSER_TESTS = qw(
     webtv          browsex     silk
     applecoremedia galeon      seamonkey
     epiphany       ucbrowser   dalvik
-    edge
+    edge           brave
 );
 
 our @IE_TESTS = qw(
@@ -198,6 +198,7 @@ my %BROWSER_NAMES = (
     aol            => 'AOL Browser',
     applecoremedia => 'AppleCoreMedia',
     blackberry     => 'BlackBerry',
+    brave          => 'Brave',
     browsex        => 'BrowseX',
     chrome         => 'Chrome',
     curl           => 'curl',
@@ -580,6 +581,13 @@ sub _init_core {
         #    $browser_string = 'Maxthon';
         #}
     }
+    elsif ( index( $ua, "brave" ) != -1 ) {
+
+        # Has to go above Chrome, it includes "like Chrome/"
+
+        $browser = 'brave';
+        $browser_tests->{$browser} = 1;
+    }
     elsif ( index( $ua, "silk" ) != -1 ) {
 
         # Has to go above Chrome, it includes "like Chrome/"
@@ -1510,6 +1518,21 @@ sub _init_version {
         $minor = $2;
         $beta  = $3;
     }
+    elsif ( $browser eq 'brave' ) {
+
+        # Note: since 0.7.10, Brave has changed the branding
+        # of GitHub's "Electron" (http://electron.atom.io/) to "Brave".
+        # This means the browser string has both "brave/" (the browser)
+        # and "Brave/" (re-branded Electron) in it.
+        # The generic section below looks at $self->{browser_string}, which is "Brave"
+        # (Electron) and not $self->{browser} which is "brave".
+        # Caveat parser.
+        if ( $ua =~ m{brave/(\d+)\.(\d+)([\d.]*)} ) {
+            $major = $1;
+            $minor = $2;
+            $beta  = $3;
+        }
+    }
     elsif ($browser eq 'chrome'
         && $ua =~ m{crios/(\d+)\.(\d+)([\d.]*)} ) {
         $major = $1;
@@ -2444,7 +2467,7 @@ HTTP::BrowserDetect - Determine Web browser, version, and platform from an HTTP
 
 =head1 VERSION
 
-version 2.07
+version 2.08
 
 =head1 SYNOPSIS
 
@@ -2511,7 +2534,7 @@ chrome, firefox, ie, opera, safari, applecoremedia, blackberry,
 browsex, dalvik, elinks, links, lynx, emacs, epiphany, galeon,
 konqueror, icab, lotusnotes, mosaic, mozilla, netfront, netscape,
 n3ds, dsi, obigo, realplayer, seamonkey, silk, staroffice, ucbrowser,
-webtv
+webtv, brave
 
 If the browser could not be identified (either because unrecognized
 or because it is a robot), returns C<undef>.
@@ -3266,7 +3289,7 @@ Olaf Alders <olaf@wundercounter.com> (current maintainer)
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Lee Semel.
+This software is copyright (c) 2016 by Lee Semel.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
